==> ejc-quality-api-3.0.0-20240308.014329-4-sources.jar: com/ejianc/business/educationtrain/vo/SpecialPersonRegisterDetailVO.java <==
package com.ejianc.business.educationtrain.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 特种人员登记-子实体
 * 
 * @author generator
 * 
 */
public class SpecialPersonRegisterDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long specialPersonRegisterId; // 特种人员登记表主表id
    private String name; // 姓名
    private String sex; // 性别
    private Integer old; // 年龄
    private String cardNum; // 证件号码
    private String expiryDate; // 有效期至
    private String memo; // 备注

    private String projectName; // 项目名称、作业项目
    private String constructionDept; // 施工单位
    

    public Long getSpecialPersonRegisterId() {
        return specialPersonRegisterId;
    }

    public void setSpecialPersonRegisterId(Long specialPersonRegisterId) {
        this.specialPersonRegisterId = specialPersonRegisterId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }
    public Integer getOld() {
        return old;
    }

    public void setOld(Integer old) {
        this.old = old;
    }
    public String getCardNum() {
        return cardNum;
    }

    public void setCardNum(String cardNum) {
        this.cardNum = cardNum;
    }
    public String getExpiryDate() {
        return expiryDate;
    }

    public void setExpiryDate(String expiryDate) {
        this.expiryDate = expiryDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getConstructionDept() {
        return constructionDept;
    }

    public void setConstructionDept(String constructionDept) {
        this.constructionDept = constructionDept;
    }
}

==> ejc-quality-api-3.0.0-20240831.033313-92-sources.jar: com/ejianc/business/educationtrain/vo/SpecialPersonRegisterDetailVO.java <==
package com.ejianc.business.educationtrain.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 特种人员登记-子实体
 * 
 * @author generator
 * 
 */
public class SpecialPersonRegisterDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long specialPersonRegisterId; // 特种人员登记表主表id
    private String name; // 姓名
    private String sex; // 性别
    private Integer old; // 年龄
    private String cardNum; // 证件号码
    private String expiryDate; // 有效期至
    private String memo; // 备注

    private String projectName; // 项目名称、作业项目
    private String constructionDept; // 施工单位

    private Long workTypeId; // 工种id
    private String workTypeName; // 工种名称

    public Long getSpecialPersonRegisterId() {
        return specialPersonRegisterId;
    }

    public void setSpecialPersonRegisterId(Long specialPersonRegisterId) {
        this.specialPersonRegisterId = specialPersonRegisterId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getSex() {
        return sex;
    }

    public void setSex(String sex) {
        this.sex = sex;
    }
    public Integer getOld() {
        return old;
    }

    public void setOld(Integer old) {
        this.old = old;
    }
    public String getCardNum() {
        return cardNum;
    }

    public void setCardNum(String cardNum) {
        this.cardNum = cardNum;
    }
    public String getExpiryDate() {
        return expiryDate;
    }

    public void setExpiryDate(String expiryDate) {
        this.expiryDate = expiryDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getConstructionDept() {
        return constructionDept;
    }

    public void setConstructionDept(String constructionDept) {
        this.constructionDept = constructionDept;
    }

    public Long getWorkTypeId() {
        return workTypeId;
    }
    @ReferDeserialTransfer
    public void setWorkTypeId(Long workTypeId) {
        this.workTypeId = workTypeId;
    }

    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
}
